The `autocomplete` value can be configured in two different locations.
The first and most secure location is to disable the `autocomplete`
attribute on the `<form>` HTML tag. This will disable `autocomplete`
for all inputs within that form. An example of disabling
`autocomplete` within the form tag is `<form autocomplete=off>`.

The second slightly less desirable option is to disable the `autocomplete`
attribute for a specific `<input>` HTML tag. While this may be the
less desired solution from a security perspective, it may be preferred
method for usability reasons, depending on size of the form. An
example of disabling the `autocomplete` attribute within a password
input tag is `<input type=password autocomplete=off>`.